/*
 nRF24 Multi-Network TX
 Version: 0.1
 Author: Alex from insideGadgets (http://www.insidegadgets.com)
 Created: 25/05/2013
 Last Modified: 8/06/2013
 
 A multi-addressable software implementation to allow for up to 256 nRF24 modules to be used at the same time.
 Each nRF24 module shares the same TX/RX address so whenever one nRF24 transmits all nearby nRF24's will receive it 
 and only accept it if it matches it's address. 
 The downside is that you need to allow for up to 20ms for a transmit or receive to occur.
 
 Variables include: From address (byte 0), To address (byte 1), Fwd address (to be implemented, byte 2), ACK (byte 3), Data (byte 4 to 31)
 
 */
 
// ATtiny25/45/85 Pin map
//                    +-\/-+
//        Reset PB5  1|o   |8  VCC
//  nRF24L01 CE PB3  2|    |7  PB2 nRF24L01 SCK
// nRF24L01 CSN PB4  3|    |6  PB1 nRF24L01 MO
//              GND  4|    |5  PB0 nRF24L01 MI
//                    +----+

#define F_CPU 1000000 // 1 MHz

#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "setup.c"
#include "mirf.c"

uint8_t data_in[32];
uint8_t data_out[32];

int main(void) {
	setup();
	mirf_init();
	_delay_ms(50);
	mirf_config();
	
	while(1) {
		
		// Clear the data_out
		for (int x = 0; x < 32; x++) {
			data_out[x] = 0; // Clear the data_out
		}
		
		// DEBUG
		/*PORTB |= (1<<PB2);
		_delay_ms(1);
		PORTB &= ~(1<<PB2);
		_delay_ms(1);*/
		
		data_out[FROM] = MYADDR;
		data_out[TO] = 2; // Address 2
		data_out[FWD] = NOFWD;
		data_out[ACK] = YESACK;
		data_out[DATA] = 143;
		
		// Send a packet and wait for an ack back
		if (send_packet_wait_ack()) {
			PORTB |= (1<<PB2);
			_delay_ms(500);
			PORTB &= ~(1<<PB2);
			_delay_ms(1000);
		}
		
		
		// Clear the data_out
		for (int x = 0; x < 32; x++) {
			data_out[x] = 0; // Clear the data_out
		}
		
		data_out[FROM] = MYADDR;
		data_out[TO] = 3; // Address 3
		data_out[FWD] = NOFWD;
		data_out[ACK] = YESACK;
		data_out[DATA] = 123;
		
		if (send_packet_wait_ack()) {
			
			PORTB |= (1<<PB2);
			_delay_ms(500);
			PORTB &= ~(1<<PB2);
			_delay_ms(1000);
		}
		
		
		// DEBUG
		/*PORTB |= (1<<PB2);
		_delay_ms(5);
		PORTB &= ~(1<<PB2);
		_delay_ms(5);*/
	}
}
